@@ -18,8 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-1-0/backends/platform/iphone/iphone_keyboard.m $
- * $Id: iphone_keyboard.m 40872 2009-05-24 21:53:29Z lordhoto $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-1-1/backends/platform/iphone/iphone_keyboard.m $
+ * $Id: iphone_keyboard.m 48478 2010-04-02 23:23:03Z vinterstum $
  *
  */
 
@@ -46,8 +46,8 @@
 	self = [super initWithFrame:CGRectMake(0.0f, 0.0f, 0.0f, 0.0f)];
 	softKeyboard = keyboard;
 
-	[[self textInputTraits] setAutocorrectionType:1];
-	[[self textInputTraits] setAutocapitalizationType:0];
+	[[self textInputTraits] setAutocorrectionType:(UITextAutocorrectionType)1];
+	[[self textInputTraits] setAutocapitalizationType:(UITextAutocapitalizationType)0];
 	[[self textInputTraits] setEnablesReturnKeyAutomatically:NO];
 
 	return self;
